"""Tables definitions"""

import django_tables2 as tables
from netbox.tables import NetBoxTable, ChoiceFieldColumn, columns
from .models import Mapping, HttpHeader


class MappingTable(NetBoxTable):
    """Mapping Table definition class"""

    authentication = ChoiceFieldColumn()
    source = tables.Column(linkify=True)
    httpheader_count = columns.LinkedCountColumn(
        viewname="plugins:netbox_rps_plugin:httpheader_list",
        url_params={"mapping_id": "pk"},
        verbose_name="HTTP Headers count",
    )
    tags = columns.TagColumn()

    class Meta(NetBoxTable.Meta):
        model = Mapping
        fields = (
            "pk",
            "id",
            "source",
            "target",
            "authentication",
            "testingpage",
            "webdav",
            "Comment",
            "httpheader_count",
            "tags",
            "created",
            "last_updated",
        )
        default_columns = (
            "source",
            "target",
            "authentication",
            "webdav",
            "httpheader_count",
        )


class HttpHeaderTable(NetBoxTable):
    """HTTP header Table definition class"""

    name = tables.Column(linkify=True)

    class Meta(NetBoxTable.Meta):
        model = HttpHeader
        fields = (
            "pk",
            "id",
            "mapping",
            "name",
            "value",
            "apply_to",
            "tags",
            "created",
            "last_updated",
        )
        default_columns = ("mapping", "name", "value", "apply_to")
